@@ -24,7 +24,7 @@
 #include <memory>
 #include <iostream>
 
-#include <json.hpp>
+#include "json.hpp"
 using nlohmann::json;
 
 
@@ -32,7 +32,7 @@ using nlohmann::json;
 #include "DeviceProfile.h"
 #include "HostCache.h"
 
-static std::string deviceprofilesfile = "tests/DeviceProfiles.json";
+static std::string deviceprofilesfile = "../tests/DeviceProfiles.json";
 
 bool test_match (std::string inIp, std::string inDpUuid, HostCache &hc);
 
