@@ -34,13 +34,13 @@
 
 
 
-#include <json.hpp>
+#include "json.hpp"
 using json = nlohmann::json;
+
 #include "Host.h"
 #include "DhcpRequest.h"
 #include "SsdpLocation.h"
 #include "FlowEntry.h"
-#include "SsdpHost.h"
 #include "DeviceProfile.h"
 
 bool Host::Match(const DeviceProfileMap& dpMap) {
@@ -72,7 +72,9 @@ bool Host::Match(const DeviceProfileMap& dpMap) {
 	}
 	if (bestmatch >= ConfidenceLevel::Low) {
 		Uuid = matcheduuid;
-		syslog(LOG_DEBUG, "Host: Host %s matched %s", Mac.c_str(), Uuid.c_str());
+		if (Debug == true) {
+		    syslog(LOG_DEBUG, "Host: Host %s matched %s", Mac.c_str(), Uuid.c_str());
+		}
 		return true;
 	}
 	return false;
@@ -143,6 +145,8 @@ bool Host::Match(const MatchCondition& mc) {
 		value = Ssdp.FriendlyName;
 	} else if (mc.Key == "SsdpManufacturer") {
 		value = Ssdp.Manufacturer;
+    } else if (mc.Key == "SsdpDeviceType") {
+        value = Ssdp.DeviceType;
 	} else if (mc.Key == "SsdpManufacturerUrl") {
 		value = Ssdp.ManufacturerUrl;
 	} else if (mc.Key == "SsdpModelName") {
@@ -161,6 +165,8 @@ bool Host::Match(const MatchCondition& mc) {
 	    value = Wsd.wsdXAddrs;
 	} else if (mc.Key == "WsDiscoveryTypes") {
 	    value = Wsd.wsdTypes;
+    } else if (mc.Key == "MdnsHostname") {
+        value = Mdns.Hostname;
 	} else if (mc.Key == "MdnsOs") {
 	    value = Mdns.Os;
 	} else if (mc.Key == "MdnsHw") {
@@ -172,8 +178,8 @@ bool Host::Match(const MatchCondition& mc) {
     } else if (mc.Key == "MdnsModelName") {
         value = Mdns.ModelName;
 	}
-	if (value == "") {
-		if(Debug) {
+	if (value == "" || std::all_of(value.begin(),value.end(),isspace)) {
+		if(Debug == true) {
 			syslog(LOG_DEBUG, "Host: Host %s has no value for MustMatch condition %s", Mac.c_str(), mc.Key.c_str());
 		}
 	}
@@ -188,6 +194,12 @@ bool Host::Match(const MatchCondition& mc) {
 		mcvalue = mcvalue.substr(0,mcvaluelength-1);
 		startpos = 0;
 	}
+    if (value.length() < mcvalue.length()) {
+        return false;
+    }
+	if (Debug == true) {
+	    syslog(LOG_DEBUG, "Host: comparing %s with %s, start position %zu, length %zu", value.c_str(), mcvalue.c_str(), startpos, mcvalue.length()-startpos);
+	}
 	if (value.compare(startpos, mcvalue.length() - startpos, mcvalue) == 0) {
 		if(Debug) {
 			syslog(LOG_DEBUG, "Host: Host %s matched MustMatch condition", Mac.c_str());
@@ -240,11 +252,13 @@ bool Host::DeviceStats(json& j, const uint32_t time_interval, bool force, bool d
 	j["SsdpManufacturerUrl"] = Ssdp.ManufacturerUrl;
 	j["SsdpModelName"] = Ssdp.ModelName;
 	j["SsdpModelUrl"] = Ssdp.ModelUrl;
+	j["SsdpDeviceType"] = Ssdp.DeviceType;
 	j["SsdpSerialNumber"] = Ssdp.SerialNumber;
 	j["SsdpUserAgent"] = Ssdp.UserAgent;
 	j["SsdpServer"] = Ssdp.Server;
     j["WsDiscoveryXaddrs"] = Wsd.wsdXAddrs;
     j["WsDiscoveryTypes"] = Wsd.wsdTypes;
+    j["MdnsHostname"] = Mdns.Hostname;
     j["MdnsOs"] = Mdns.Os;
     j["MdnsHw"] = Mdns.Hw;
     j["MdnsDeviceUrl"] = Mdns.DeviceUrl;
